============
Installation
============


The following will not yet work, though it is the intent.  Please
refer to the :doc:`quickstart` while we are in active development.

---

At the command line::

    $ pip install kolla-kubernetes

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv kolla-kubernetes
    $ pip install kolla-kubernetes
